@@ -76,7 +76,7 @@ SEXP minimize_by_enumeration(SEXP n_items_sexp, SEXP psm_sexp, SEXP use_vilb_sex
   return results_labels_sexp;
 }
 
-SEXP minimize_by_salso(SEXP n_items_sexp, SEXP psm_sexp, SEXP use_vilb_sexp, SEXP max_size_sexp, SEXP max_scans_sexp, SEXP n_permutations_sexp, SEXP seconds_sexp, SEXP parallel_sexp) {
+SEXP minimize_by_salso(SEXP n_items_sexp, SEXP psm_sexp, SEXP use_vilb_sexp, SEXP max_size_sexp, SEXP max_scans_sexp, SEXP n_permutations_sexp, SEXP probability_of_exploration_sexp, SEXP seconds_sexp, SEXP parallel_sexp, SEXP seed_sexp) {
   int n_items = Rf_asInteger(n_items_sexp);
   psm_sexp = PROTECT(Rf_coerceVector(psm_sexp, REALSXP));
   double *psm = REAL(psm_sexp);
@@ -84,6 +84,7 @@ SEXP minimize_by_salso(SEXP n_items_sexp, SEXP psm_sexp, SEXP use_vilb_sexp, SEX
   int max_size = Rf_asInteger(max_size_sexp);
   int max_scans = Rf_asInteger(max_scans_sexp);
   int n_permutations = Rf_asInteger(n_permutations_sexp);
+  double probability_of_exploration = Rf_asReal(probability_of_exploration_sexp);
   double seconds = Rf_asReal(seconds_sexp);
   int parallel = Rf_asLogical(parallel_sexp);
   SEXP results_labels_sexp = PROTECT(Rf_allocVector(INTSXP, n_items));
@@ -94,7 +95,8 @@ SEXP minimize_by_salso(SEXP n_items_sexp, SEXP psm_sexp, SEXP use_vilb_sexp, SEX
   int *results_n_scans = INTEGER(results_n_scans_sexp);
   SEXP results_actual_n_permutations_sexp = PROTECT(Rf_allocVector(INTSXP, 1));
   int *results_actual_n_permutations = INTEGER(results_actual_n_permutations_sexp);
-  dahl_salso__minimize_by_salso(n_items, psm, loss, max_size, max_scans, n_permutations, seconds, parallel, results_labels, results_expected_loss, results_n_scans, results_actual_n_permutations);
+  int *seed = INTEGER(seed_sexp);
+  dahl_salso__minimize_by_salso(n_items, psm, loss, max_size, max_scans, n_permutations, probability_of_exploration, seconds, parallel, results_labels, results_expected_loss, results_n_scans, results_actual_n_permutations, seed);
   SEXP results = PROTECT(Rf_allocVector(VECSXP, 5));
   SET_VECTOR_ELT(results, 0, results_labels_sexp);
   SET_VECTOR_ELT(results, 2, results_expected_loss_sexp);
@@ -112,7 +114,7 @@ static const R_CallMethodDef CallEntries[] = {
   {".lbell", (DL_FUNC) &lbell, 1},
   {".enumerate_partitions", (DL_FUNC) &enumerate_partitions, 1},
   {".minimize_by_enumeration", (DL_FUNC) &minimize_by_enumeration, 3},
-  {".minimize_by_salso", (DL_FUNC) &minimize_by_salso, 8},
+  {".minimize_by_salso", (DL_FUNC) &minimize_by_salso, 10},
   {NULL, NULL, 0}
 };
 
